SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `ma` DEFAULT CHARACTER SET latin1 ;
USE `ma`;

-- -----------------------------------------------------
-- Table `ma`.`server_group`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `ma`.`server_group` (
  `idx` INT(11) NOT NULL AUTO_INCREMENT ,
  `group_name` CHAR(30) NOT NULL ,
  `comment` TINYBLOB NULL DEFAULT NULL ,
  PRIMARY KEY (`idx`) )
ENGINE = MyISAM
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `ma`.`servers`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `ma`.`servers` (
  `idx` INT(11) NOT NULL AUTO_INCREMENT ,
  `server_ip` CHAR(30) NOT NULL ,
  `server_name` CHAR(30) NOT NULL ,
  `server_group` CHAR(30) NULL DEFAULT NULL ,
  `server_userid` CHAR(30) NULL DEFAULT NULL ,
  `server_userpw` CHAR(30) NULL DEFAULT NULL ,
  `comment` TINYBLOB NULL DEFAULT NULL ,
  PRIMARY KEY (`idx`) ,
  INDEX `fk_servers_1` (`server_group` ASC) ,
  CONSTRAINT `fk_servers_1`
    FOREIGN KEY (`server_group` )
    REFERENCES `ma`.`server_group` (`group_name` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
AUTO_INCREMENT = 5
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `ma`.`mod_manage`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `ma`.`mod_manage` (
  `idx` INT(11) NULL AUTO_INCREMENT ,
  `mod_name` CHAR(30) NOT NULL ,
  `mod_type` CHAR(30) NOT NULL ,
  `reaction` CHAR(30) NOT NULL ,
  `alert` CHAR(30) NOT NULL ,
  `comment` TINYBLOB NULL DEFAULT NULL ,
  `file` CHAR(30) NULL DEFAULT NULL ,
  PRIMARY KEY (`idx`) ,
  UNIQUE INDEX `mod_name` (`mod_name` ASC) )
ENGINE = MyISAM
AUTO_INCREMENT = 3
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `ma`.`alert_log`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `ma`.`alert_log` (
  `idx` INT(11) NOT NULL AUTO_INCREMENT ,
  `mod_name` CHAR(30) NOT NULL ,
  `log` CHAR(50) NOT NULL ,
  `server` CHAR(30) NOT NULL ,
  `level` VARCHAR(45) NULL ,
  `date` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  PRIMARY KEY (`idx`) ,
  INDEX `fk_alert_log_1` (`server` ASC) ,
  INDEX `fk_alert_log_2` (`mod_name` ASC) ,
  CONSTRAINT `fk_alert_log_1`
    FOREIGN KEY (`server` )
    REFERENCES `ma`.`servers` (`server_ip` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_alert_log_2`
    FOREIGN KEY (`mod_name` )
    REFERENCES `ma`.`mod_manage` (`mod_name` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `ma`.`resource_mon`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `ma`.`resource_mon` (
  `idx` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `mod_name` CHAR(30) NULL ,
  `server_ip` CHAR(30) NOT NULL ,
  `now_usage` INT(10) UNSIGNED NOT NULL ,
  `total` INT(10) UNSIGNED NOT NULL ,
  `date` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  PRIMARY KEY (`idx`) ,
  INDEX `server_ip` (`server_ip` ASC) ,
  INDEX `fk_resource_mon_1` (`server_ip` ASC) ,
  INDEX `fk_resource_mon_2` (`mod_name` ASC) ,
  CONSTRAINT `fk_resource_mon_1`
    FOREIGN KEY (`server_ip` )
    REFERENCES `ma`.`servers` (`server_ip` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_resource_mon_2`
    FOREIGN KEY (`mod_name` )
    REFERENCES `ma`.`mod_manage` (`mod_name` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
AUTO_INCREMENT = 156
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `ma`.`server_mod`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `ma`.`server_mod` (
  `idx` INT(11) NOT NULL AUTO_INCREMENT ,
  `mod_name` CHAR(30) NOT NULL ,
  `server_name` CHAR(30) NOT NULL ,
  `value` CHAR(30) NULL DEFAULT NULL ,
  `reaction` CHAR(30) NULL DEFAULT 'n' ,
  `alert` CHAR(30) NULL DEFAULT 'n' ,
  `warning` VARCHAR(45) NULL DEFAULT 'warning' ,
  PRIMARY KEY (`idx`) ,
  INDEX `fk_server_mod_1` (`server_name` ASC) ,
  INDEX `fk_server_mod_2` (`mod_name` ASC) ,
  CONSTRAINT `fk_server_mod_1`
    FOREIGN KEY (`server_name` )
    REFERENCES `ma`.`servers` (`server_ip` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_server_mod_2`
    FOREIGN KEY (`mod_name` )
    REFERENCES `ma`.`mod_manage` (`mod_name` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
AUTO_INCREMENT = 34
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `ma`.`setting`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `ma`.`setting` (
  `set_name` CHAR(30) NOT NULL ,
  `set_type` CHAR(30) NOT NULL ,
  `set_value` CHAR(30) NOT NULL ,
  `comment` TINYBLOB NULL DEFAULT NULL ,
  PRIMARY KEY (`set_name`) )
ENGINE = MyISAM
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `ma`.`user`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `ma`.`user` (
  `idx` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `user_name` VARCHAR(30) NOT NULL ,
  `password` VARCHAR(30) NOT NULL ,
  `comment` TINYBLOB NULL DEFAULT NULL ,
  PRIMARY KEY (`idx`) )
ENGINE = MyISAM
AUTO_INCREMENT = 2
DEFAULT CHARACTER SET = latin1;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
